# Examples

There are some example calculations given with different usage scenarios. Please send us more calculations to include here.

## dftsolve.py Example List

| Name              | Notes  | 
| ----------------- | ------ |
| Bulk-GaAs-noCIF   | Ground, DOS, and Band calculations of bulk GaAs with PW. Positions are given with an Atom object.          |
| Cr2O-spin         |Spin-dependent electronic properties of CrO2 |
| Graphene-LCAO     | Pristine graphene and graphene with a defect with LCAO. Uses a single config for two calculations. |
| Graphene-Charged  | Effect of charge in graphene with a defect with LCAO  |
| Si-2atoms-optical | Three-step calculation. First step: ground, DOS, and Band calculations. Second and third steps for RPA and BSE optical calculations, respectively. Structure is given with a CIF file. |
| Al-phonon         | Phonon dispersion calculation of bulk Aluminum |
| ZnO with DFT+U    | Wurtzite ZnO calculation with DFT+U. Positions are given with the Bulk object. Hubbard params are: O-p: 7eV, Zn-d: 10eV|
| TiC-elastic-electronic | Elastic (EoS and Elastic Tensor) and Electronic Properties of Rocksalt TiC |
| Si-with-HSE | Ground state, DOS, and band structure of Si with HSE06 Hybrid XC |
| Si-qe       | Example for QE to Nanoworks conversion with qeconverter |
| Si-vasp       | Example for VASP to Nanoworks conversion with vaspconverter |


## mdsolve.py Example List

| Name              | Notes  | 
| ----------------- | ------ |
| ASAP3-Example     | Germanene nanosheet example with a general potential.          |
